<?php
namespace Fiscal\Logic\Impostos;

use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use Setforms2\Shared\Registry;

class Imposto {
    
    public static function validacaoImpostoJaExistenteNFE($cdimposto) {
        try {
            $validacaoImpostos = new ValidacaoImpostos();
            $validacaoImpostos->validaImpostoJaExistenteNFE($cdimposto);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public static function validacaoImpostoJaExistenteXML($cdimposto) {
        try {
            $validacaoImpostos = new ValidacaoImpostos();
            $validacaoImpostos->validaImpostoJaExistenteXML($cdimposto);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function validacaoImpostoMapa($cdimposto) {
        try {
            $validacaoImpostos = new ValidacaoImpostos();
            $validacaoImpostos->validaImpostoMapa($cdimposto);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function updateRelacionamentoImpostoNFE($cdimposto, $cdimpostonfe = null) {
        $nrorg = Ambiente::getNrorg();
        $imposto = \Geral\Entities\Imposto::findOneByCdimpostoAndNrorg($cdimposto, $nrorg);

        $imposto->setCdimpostonfe($cdimpostonfe);
        $imposto->persist();
        Registry::getEntityManager()->flush();
    }
    
    public static function updateRelacionamentoImpostoXML($cdimposto, $cdimpostoxml = null) {
        $nrorg = Ambiente::getNrorg();
        /* @var $imposto \Geral\Entities\Imposto */
        $imposto = \Geral\Entities\Imposto::findOneByCdimpostoAndNrorg($cdimposto, $nrorg);

        $imposto->setCdimpostoxml($cdimpostoxml);
        $imposto->persist();
        Registry::getEntityManager()->flush();
    }
    
    public static function verificarImpostosPadraoNFE($data) {
        $array_impostos = array();
        foreach ($data as $imposto) {
            $array_impostos[$imposto['CDIMPOSTONFE']] = $imposto['SGIMPOSTONFE'];
        }

        $impostosPadraoNFE = array(
            '00' => 'ICMS',
            '03' => 'CARGA RJ',
            '10' => 'IPI',
            '20' => 'II',
            '21' => 'IRRF-E',
            '22' => 'IRRF-S',
            '25' => 'IRPJ',
            '26' => 'FUNRURAL',
            '30' => 'ISSQN-E',
            '31' => 'ISSQN-S',
            '35' => 'ISS-RET-E',
            '36' => 'ISS-RET-S',
            '40' => 'IOF',
            '41' => 'INSS-RET-E',
            '42' => 'INSS-RET-S',
            '50' => 'PIS',
            '55' => 'PIS-RET-E',
            '56' => 'PIS-RET-S',
            '60' => 'COFINS',
            '65' => 'COF-RET-E',
            '66' => 'COF-RET-S',
            '70' => 'CSLL',
            '75' => 'CSLL-RET-E',
            '76' => 'CSLL-RET-S',
            '80' => 'ICMS ST',
            '85' => 'PIS ST',
            '90' => 'COFINS ST'
        );

        return array_diff_assoc($impostosPadraoNFE, $array_impostos);
    }
    
    public static function adicionarImpostoNFE($impostosAdicionar){
        foreach ($impostosAdicionar as $i => $imposto) {
            $impostoNFE = new \Indeterminado\Entities\Impostonfe();
            $impostoNFE->setCdimpostonfe($i);
            $impostoNFE->setSgimpostonfe($imposto);
            $impostoNFE->setNrorg(Ambiente::getNrorg());
            $impostoNFE->setNrorginclusao(Ambiente::getNrorg());
            $impostoNFE->setNrorgultatu(Ambiente::getNrorg());
            $impostoNFE->setDtinclusao(DateUtil::getDataAtual());
            $impostoNFE->setDtultatu(DateUtil::getDataAtual());
            $impostoNFE->persist();
            
            Registry::getEntityManager()->flush();
        }
    }

    public static function atualizaFieldImportaArquivoXML($nrorg, $cdimposto){
        try{
            $imposto = \Geral\Entities\Imposto::findOneByNrorgAndCdimposto($nrorg, $cdimposto);
            if($imposto->getIdimportaimpxml() === 'N'){
                $imposto->setIdimportaimpxml('S');
            }else if($imposto->getIdimportaimpxml() === 'S'){
                $imposto->setIdimportaimpxml('N');
            }else if(!$imposto){
                tk_set_field_value('IDIMPORTAIMPXML',null);
            }
            $imposto->persist();
            Registry::getEntityManager()->flush();

        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function alteraImpostoNfeParametrizacao($orgaoArrecadador, $impostoRecuperavel, $organizacao, $codigoImpostonfe, $impostonfe){
        try {
            if ($orgaoArrecadador != $impostonfe->getIdorgarrecadnfe() or $impostoRecuperavel != $impostonfe->getIdimporecupnfe()) {
                $grupoimpostos = \Geral\Entities\Imposto::getObjectsByWhere(
                    'CDIMPOSTONFE = ? and NRORG = ? ',
                    array($codigoImpostonfe, $organizacao)
                );
                foreach ($grupoimpostos as $impostogrupo) {
                    $impostogrupo->setIdorgarrecad($orgaoArrecadador);
                    $impostogrupo->setIdimporecup($impostoRecuperavel);
                    $impostogrupo->persist();
                    Registry::getEntityManager()->flush();
                }
                $impostonfe->setIdorgarrecadnfe($orgaoArrecadador);
                $impostonfe->setIdimporecupnfe($impostoRecuperavel);
                $impostonfe->persist();
                Registry::getEntityManager()->flush();
                return true;
            }
            return false;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function alteraImpostoNfeFiscal($apuracaoImposto, $organizacao, $codigoImpostonfe, $impostonfe){
        try {
            if ($apuracaoImposto != $impostonfe->getIdformapurnfe()) {
                $grupoimpostos = \Geral\Entities\Imposto::getObjectsByWhere(
                    'CDIMPOSTONFE = ? and NRORG = ? ',
                    array($codigoImpostonfe, $organizacao)
                );
                foreach ($grupoimpostos as $impostogrupo) {
                    $impostogrupo->setIdformapur($apuracaoImposto);
                    $impostogrupo->persist();
                    Registry::getEntityManager()->flush();
                }
                $impostonfe->setIdformapurnfe($apuracaoImposto);
                $impostonfe->persist();
                Registry::getEntityManager()->flush();
                return true;
            }
            return false;
        } catch (\Exception $e) {
            throw $e;
        }
    }
}