module.exports = function(grunt){
    var jsonPath = 'json/**/*.json';
    var configPath = 'config/LibConfig.js';
    var configSaasPath = 'config/LibConfig_server.js';
    var utilPath = 'js/Util/**/*.js';
    var repositoryPath = 'src/repositories/*.js';
    var servicePath = 'src/services/*.js';
    var controllerPath = 'src/controllers/*.js';

    grunt.initConfig({

        // grunt-contrib-concat
        concat: {
            zh: {
                options: {
                    process: function(src, filePath){
                        return '\n' + '// FILE: ' + filePath + '\n' + src;
                    }
                },
                src: [
                    configPath, utilPath, repositoryPath, servicePath, controllerPath
                ],
                dest: 'dist/main.js'
            }
        },

        // grunt-contrib-jshint
        jshint: {
            all: ['Gruntfile.js', './js/Util/**/*.js', './js/Service/**/*.js', './js/Controller/**/*.js']
        },

        // grunt-contrib-uglify
        uglify: {
            options: {
                mangle: false,
                compress: false,
                report: 'min',
                banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
            },
            dist: {
                files: {
                    'dist/main.min.js': [configPath, utilPath, repositoryPath, servicePath, controllerPath]
                }
            }
        },

        // grunt-contrib-watch
        watch: {
            pivotal: {
                files: [configPath, utilPath, repositoryPath, servicePath, controllerPath],
                tasks: ['jshint', 'uglify', 'concat']
            }
        },
        bump: {
            options: {
                files: ['bower.json'],
                pushTo: 'origin',
                commitFiles: ["-a"],
                push: true
            }
        },
        zhWords: {
            options: {
                serverUrl: "https://translate.teknisa.com/backend/index.php",
                organization: "20",
                project: "4495"
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-bump');
    grunt.loadNpmTasks('grunt-zh-words');

    grunt.registerTask('default', ['uglify', 'concat']);
    grunt.registerTask('basic', ['concat']);
};